@@ -16,11 +16,6 @@ class X:
 #:
 
 
-#: E302:3:1
-#!python
-# -*- coding: utf-8 -*-
-def a():
-    pass
 #: E302:2:1
 """Main module."""
 def _main():
@@ -129,6 +124,11 @@ def a():
     x = 1
     def b():
         pass
+#: E306:3:5
+async def a():
+    x = 1
+    def b():
+        pass
 #: E306:3:5 E306:5:9
 def a():
     x = 2
@@ -181,3 +181,11 @@ def foo():
     def bar(): pass
     def baz():
         pass
+#: E302:5:1
+def f():
+    pass
+
+# wat
+@hi
+def g():
+    pass
